// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KITEMMODELS_VERSION_H
#define KITEMMODELS_VERSION_H

#define KITEMMODELS_VERSION_STRING "6.26.0"
#define KITEMMODELS_VERSION_MAJOR 6
#define KITEMMODELS_VERSION_MINOR 26
#define KITEMMODELS_VERSION_PATCH 0
#define KITEMMODELS_VERSION ((6<<16)|(26<<8)|(0))

#endif
